**************************************************************
*
*	Procedure Name:	GPStart()
*
*	Parameters:		N/A
*
*	Return values:	.T. if GPLIB is able to load correctly.
*
*	Description:
*
*
*	Because GPLIB requires the Novell DLLs, and Unicode(NDS) to
*	load correctly, this function encapsulates all of the code
*	necessary to make sure that GPLIB will load.
*
**************************************************************

LOCAL cOS, cLastErr, cError, nFoxVer, lClient32

IF 'GPLIB.FLL' $ set('LIBRARY')
	RETURN .t.
EndIf

DO case
CASE version()="Visual FoxPro 03"
	nFoxVer=3
CASE version()="Visual FoxPro 05"
	nFoxVer=5
CASE version()="Visual FoxPro 06"
	nFoxVer=5

OTHERWISE
*	do form ShowMsg with "FOX_VER"
	return .f.
ENDCASE

lClient32=.f.
COS=os(1)

IF !CheckDLLS(cOS, nFoxVer,@lClient32)
	RETURN .f.
EndIf
cError=''
cLastErr=on('ERROR')

do case
case nFoxVer==3
	if lClient32
		set path to ..\VFP3CL32
	else
		set path to ..\VFP_W16
	endif
case nFoxVer==5

	set path to ..\VFP5CL32

endcase

ON error store message() to cError

SET library to (locfile('gplib.fll','FLL','Where is GPLIB.FLL?'))

ON error &cLastErr
IF !empty(cError)
*	DO form ShowMsg with "DIDNT_LOAD"
	RETURN .f.
EndIf

IF empty(N_ShellVer())
	*
	*	Make Sure the Novell Drivers are Loaded
	*	This really should not happen with GPLIB 3
	*
*	DO form ShowMsg with "NO_SHELL"
	RETURN .f.
EndIf

IF N_IsDS()
	*
	*	Check if the station is connected to a 4.x
	*	Directory services server.  If so, make sure
	*	the unicode tables loaded properly.
	*
	IF !N_UniReady()
		do NoUnicode
		RETURN .t.
	EndIf
EndIf

FUNCTION CheckDLLS
	**************************************************************
	*
	*	Procedure Name:	CheckDLLs
	*
	*	Parameters:		cOS, the operating system we are on
	*					nFoxVer, the version of FoxPro we are on
	*
	*	Return values:	N/A, cancels on an error
	*
	*	Description:
	*
	*	This function checks to ensure that the required Novell
	*	DLLs are present on the system before running the
	*	demonstration program.  If they are not found, an
	*	appropriate message displayed, and the demo program
	*	is cancelled.
	*
	**************************************************************
	PARAMETER cOS, nFoxVer, lClient32

	LOCAL cBuf, cSystemDir, nHandle, lResult, cDate

	DECLARE integer GetSystemDirectory in Win32API String @ lpBuffer, integer uSize
	cBuf=replicate(chr(0),255)
	set date to american
	=GetSystemDirectory(@cBuf,len(cBuf))
	cSystemDir=CopyZStr(cBuf)

	if file(cSystemDir+'\CALWIN32.DLL')
		DECLARE integer LoadLibrary in Win32API string

		nHandle=LoadLibrary('CALWIN32.DLL')
		IF nHandle > 0
			lClient32=.t.
			DECLARE FreeLibrary in win32API integer
			=FreeLibrary(nHandle)
		EndIf
	ENDIF
	
	lResult=.f.
	DO case
	CASE lClient32
		lResult=.t.
	CASE cOs="Windows NT"
*		DO form ShowMsg with "CL32_REQ"
	CASE cOs="Windows 4" .or. cOS="Windows 3"
		IF nFoxVer==5
*			DO form ShowMsg with "CL32_REQ"
		ELSE
			cDate=set('DATE')
			IF isDLLAround(cSystemDir,"NWCALLS.DLL",{10/20/1994})==.F. ;
			 .or. isDLLAround(cSystemDir,"NWLOCALE.DLL",{02/28/1994})==.F. ;
			 .or. isDLLAround(cSystemDir,"NWNET.DLL",{03/01/1994})==.F.
*				DO form ShowMsg with "WIN3_DLLS"
			else
				lResult=.t.
			EndIf
			set date to &cDate
		EndIf
	ENDCASE
	RETURN lResult


FUNCTION isDLLAround
	**************************************************************
	*
	*	Function Name:	IsDLLAround()
	*
	*	Parameters:		cSystemDir, Windows System directory
	*					cDLLName, name of the DLL
	*
	*	Return Values:
	*
	*		.T. if specified DLL exists in the WINDOWS\SYSTEM
	*		Directory, or in the path.
	*
	**************************************************************
	PARAMETER cSystemDir, cDLLName, dMinimum
	local lResult, cFile
	lResult=.f.
	cFile=cSystemDir+'\'+cDLLName
	IF !file(cFile)
		cFile=fullPath(cDLLName,1)
	EndIf
	lResult=file(cFile)
	
	if lResult .AND. empty(dMinimum)==.F.
		lResult=lResult .AND. (GetFileDate(cFile) >= dMinimum)
	endif
	return lResult

Function GetFileDate
	**************************************************************
	*
	*	Function Name:	GetFileDate()
	*
	*	Parameters:		cFile, name of file to get date for.
	*
	*	Return Values:
	*
	*		Date stamp of file if it exists, {} otherwise
	*
	**************************************************************
	LPARAMETERS cFile

	if adir(aTemp,cFile)==1
		return aTemp[1,3]
	endif
	return {}




PROCEDURE NoUnicode
	**************************************************************
	*
	*	This procedure copies the Unicode tables into the \WINDOWS directory.
	*	The unicode tables are required when using GPLIB with NetWare 4.x and
	*	directory services.
	*
	**************************************************************

	PRIVATE nCountry, nCodePage, cCountry, cCodePage, cWinDir, ;
	 cNLSDir, aFiles, cServerPath, nServers

	EXTERNAL array aServers

	nCountry=0
	nCodePage=0
	=N_UniReady(@nCountry,@nCodePage)
	cCountry=padl(nCountry,3,'0')
	cCodePage=ltrim(str(nCodePage))
	USE GPMSG
	LOCATE for msgID='NO_UNICODE'
	REPLACE MsgText with strtran(MsgText,'<CP>',cCodePage)
	REPLACE MsgText with strtran(MsgText,'<CTY>',cCountry)
	USE
	DECLARE aFiles[4]

	aFiles[1]='UNI_'+cCodePage+'.'+cCountry
	aFiles[2]=cCodePage+'_UNI'+'.'+cCountry
	aFiles[3]='UNI_COL.'+cCountry
	aFiles[4]='UNI_MON.'+cCountry


*	DO form ShowMsg with 'NO_UNICODE','Unicode Table Problem'

	DECLARE integer GetWindowsDirectory in Win32API String @ lpBuffer, integer uSize
	cWinDir=replicate(chr(0),255)
	=GetWindowsDirectory(@cWinDir,len(cWinDir))
	cWinDir=CopyZStr(cWinDir)
	IF (right(cWinDir,1)!='\')
		cWinDir=cWinDir+'\'
	EndIf
	cNLSDir=cWinDir+'NLS'

	IF MessageBox('Do you wish to copy the Unicode tables to the directory '+cNLSDir+'?',33,'GPLIB Demonstration Program')!=1
		RETURN
	EndIf


	=Make_Dir(cNLSDir)
	IF aDir(atest,cNLSDir,'D')==0
		=MessageBox('Unable to create NLS directory in '+cWinDir+'!  Copy Aborted!',16)
		RETURN
	EndIf
	nServers=N_Servers('ASERVERS')
	FOR n=1 to nServers
		IF N_IsDS(aServers[n])
			FOR nInner=1 to alen(aFiles,1)
				* copy the NLS files we need from the \login directory on the
				* sys volume of a NDS Server
				cServerPath="\\"+aServers[n]+'\sys\login\nls\'
				COPY file (cServerPath+aFiles[nInner]) to (cNLSDir+'\'+aFiles[nInner])
			ENDFOR
			IF (messageBox('Files successfully copied.  Exit Windows?',1)==1)
				=ColdBoot()
			EndIf
		EndIf
	ENDFOR
	RETURN
		
